/* Copyright (C) 2000-2003 Markus Lausser (sgop@users.sf.net)
   This is free software distributed under the terms of the
   GNU Public License.  See the file COPYING for details. */

#ifndef _FILES_H_
#define _FILES_H_

#include "lopster.h"

file_t* file_new();
void file_destroy(gpointer data);
void file_set_longname(file_t* file, char* name);
void file_set_winname(file_t* file, char* name);
file_t* file_create_from_browse_response(net_t* net, char *data);
file_t* file_create_from_search_response(net_t* net, char *data);
int file_compare(file_t* file1, file_t* file2);
file_t* file_duplicate(file_t * file);
void play_file(char *filename, char* app);

#endif
